@@ -8,7 +8,8 @@
 #' }
 ma_abstract <- function(query, count = 10, offset = 0, orderby = NULL,
                         model = "latest", key = NULL, ...) {
-  out <- ma_evaluate(query, count, offset, orderby, c("Id", "E"), model, key, ...)
+  out <- ma_evaluate(query, count, offset, orderby, c("Id", "E"), 
+    model, key, ...)
   unname(vapply(out$E, function(z) invabs2abs(jsonlite::fromJSON(z)$IA), ""))
 }
 
