@@ -4,12 +4,12 @@ test_that("ma_evaluate works as expected", {
   skip_on_cran()
   Sys.sleep(1)
 
-  aa <- ma_evaluate(query = "Ti='biology'...")
+  aa <- ma_evaluate(query = "Y='19'...")
 
   expect_is(aa, "tbl_df")
-  expect_named(aa, c('logprob', 'Id', 'E', 'Ti', 'Y', 'CC', 'AA', 'J.JN'))
+  expect_named(aa, c('logprob', 'Id', 'Ti', 'Y', 'CC', 'AA', 'E', 'J.JN'))
 
   expect_type(aa$logprob, "double")
-  expect_type(aa$Id, "integer")
+  expect_type(aa$Id, "double")
   expect_type(aa$E, "character")
 })
